==> forestry_1.9.4-5.0.10.147-api.jar: forestry/api/multiblock/IMultiblockComponent.java <==
/*******************************************************************************
 * Copyright 2011-2014 SirSengir
 *
 * This work (the API) is licensed under the "MIT" License, see LICENSE.txt for details.
 ******************************************************************************/
package forestry.api.multiblock;

import net.minecraft.util.math.BlockPos;

import com.mojang.authlib.GameProfile;

/**
 * Basic interface for a multiblock machine component.
 * Implemented by TileEntities.
 */
public interface IMultiblockComponent {
	
	/**
	 * Returns the location of this tile entity in the world.
	 * @return ChunkCoordinates set to the location of this tile entity in the world.
	 */
	BlockPos getCoordinates();

	/**
	 * @return the gameProfile of the player who owns this single component (not the entire multiblock)
	 */
	GameProfile getOwner();

	/**
	 * @return the multiblock logic for this part
	 */
	IMultiblockLogic getMultiblockLogic();

	/**
	 * Called when a machine is fully assembled from the disassembled state, meaning
	 * it was constructed by a player/entity action, not by chunks loading.
	 * Note that, for non-square machines, the min/max coordinates may not actually be part
	 * of the machine! They form an outer bounding box for the whole machine itself.
	 * @param multiblockController The controller to which this part is being assembled.
	 */
	void onMachineAssembled(IMultiblockController multiblockController, BlockPos minCoord, BlockPos maxCoord);

	/**
	 * Called when the machine is broken for game reasons, e.g. a player removed a block
	 * or an explosion occurred.
	 */
	void onMachineBroken();
}

==> forestry-1.20.1-2.8.0-api.jar: forestry/api/multiblock/IMultiblockComponent.java <==
package forestry.api.multiblock;

import com.mojang.authlib.GameProfile;
import forestry.core.inventory.IInventoryAdapter;
import net.minecraft.core.BlockPos;

import javax.annotation.Nullable;

/**
 * Basic interface for a multiblock machine component.
 * Implemented by TileEntities.
 */
public interface IMultiblockComponent {
	/**
	 * Returns the location of this tile entity in the world.
	 *
	 * @return ChunkCoordinates set to the location of this tile entity in the world.
	 */
	BlockPos getCoordinates();

	/**
	 * @return the gameProfile of the player who owns this single component (not the entire multiblock)
	 */
	@Nullable
	GameProfile getOwner();

	/**
	 * @return the multiblock logic for this part
	 */
	IMultiblockLogic getMultiblockLogic();

	/**
	 * Called when a machine is fully assembled from the disassembled state, meaning
	 * it was constructed by a player/entity action, not by chunks loading.
	 * Note that, for non-square machines, the min/max coordinates may not actually be part
	 * of the machine! They form an outer bounding box for the whole machine itself.
	 *
	 * @param multiblockController The controller to which this part is being assembled.
	 */
	void onMachineAssembled(IMultiblockController multiblockController, BlockPos minCoord, BlockPos maxCoord);

	/**
	 * Called when the machine is broken for game reasons, e.g. a player removed a block
	 * or an explosion occurred.
	 */
	void onMachineBroken();

	/**
	 * A component with a separate inventory, like the Alveary Swarmer or Alveary Sieve.
	 */
	interface HasInventory {
		/**
		 * Called when this part is destroyed to drop its contents.
		 */
		IInventoryAdapter getInternalInventory();
	}
}
